@@ -9,9 +9,10 @@ from ._categories import CATEGORIES
 from ._gui import Assistant
 from ._gui._category_widget import make_gui_for_category
 from ._statistics_of_labeled_pixels import statistics_of_labeled_pixels
-from ._convert_to_numpy import convert_to_numpy, convert_to_2d_timelapse, make_labels_editable, \
+from ._convert_to_numpy import convert_to_numpy, make_labels_editable, \
     reset_brightness_contrast, auto_brightness_contrast, split_stack, auto_brightness_contrast_all_images, \
     set_voxel_size, set_voxel_size_of_all_layers, convert_labels_to_image, convert_image_to_labels
+from ._napari_cle_functions import label, voronoi_otsu_labeling
 from ._categories import attach_tooltips
 from skimage.io import imread
 
@@ -80,5 +81,6 @@ def napari_experimental_provide_function():
         convert_image_to_labels,
         convert_labels_to_image,
         convert_to_numpy,
-        convert_to_2d_timelapse
+        label,
+        voronoi_otsu_labeling
     ]
\ No newline at end of file
